import { v4 as uuidv4 } from "uuid"
import type { Simulation } from "./debutant"

const avanceSimulations: Simulation[] = [
  {
    id: uuidv4(),
    title: "Simulation avancé #1",
    description: "Première simulation pour les conducteurs de niveau avancé",
    duration: 30,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le dépassement d'un véhicule à l'approche d'un virage ?",
        options: [
          "Autorisé si la visibilité est bonne",
          "Autorisé si aucun véhicule ne vient en face",
          "Interdit dans tous les cas",
          "Autorisé uniquement de jour",
        ],
        correctAnswer: "Interdit dans tous les cas",
        explanation:
          "Le dépassement est interdit à l'approche d'un virage ou au sommet d'une côte, car la visibilité est insuffisante pour s'assurer que la manœuvre peut être effectuée en toute sécurité.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation des feux de route en agglomération ?",
        options: [
          "Obligatoire la nuit",
          "Interdite",
          "Autorisée sur les voies rapides urbaines",
          "Obligatoire par temps de pluie",
        ],
        correctAnswer: "Interdite",
        explanation:
          "L'utilisation des feux de route (pleins phares) est interdite en agglomération car ils éblouissent les autres usagers et les riverains. On utilise les feux de croisement.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le franchissement d'une ligne discontinue ?",
        options: [
          "Interdit dans tous les cas",
          "Autorisé pour dépasser uniquement",
          "Autorisé pour dépasser ou tourner",
          "Autorisé uniquement pour les véhicules prioritaires",
        ],
        correctAnswer: "Autorisé pour dépasser ou tourner",
        explanation:
          "Le franchissement d'une ligne discontinue est autorisé pour effectuer un dépassement ou pour changer de direction, à condition de respecter les règles de sécurité.",
      },
      {
        id: uuidv4(),
        question:
          "Quelle est la vitesse maximale autorisée sur une route à double sens hors agglomération pour un conducteur novice ?",
        options: ["70 km/h", "80 km/h", "90 km/h", "110 km/h"],
        correctAnswer: "80 km/h",
        explanation:
          "Pour un conducteur novice (permis probatoire), la vitesse maximale autorisée sur une route à double sens hors agglomération est de 80 km/h, comme pour les autres conducteurs.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le stationnement à proximité d'une intersection ?",
        options: [
          "Autorisé à plus de 5 mètres",
          "Autorisé à plus de 10 mètres",
          "Interdit à moins de 5 mètres",
          "Interdit à moins de 10 mètres",
        ],
        correctAnswer: "Interdit à moins de 5 mètres",
        explanation:
          "Le stationnement est interdit à moins de 5 mètres d'une intersection pour ne pas gêner la visibilité et la circulation des véhicules.",
      },
    ],
  },
  {
    id: uuidv4(),
    title: "Simulation avancé #2",
    description: "Deuxième simulation pour les conducteurs de niveau avancé",
    duration: 30,
    questions: [
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation du frein moteur en descente ?",
        options: [
          "Déconseillée car elle use le moteur",
          "Recommandée pour économiser les freins",
          "Interdite sur autoroute",
          "Obligatoire sur route mouillée",
        ],
        correctAnswer: "Recommandée pour économiser les freins",
        explanation:
          "L'utilisation du frein moteur en descente est recommandée car elle permet d'économiser les freins et d'éviter leur surchauffe, tout en maintenant une bonne maîtrise du véhicule.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le dépassement d'un tramway ?",
        options: [
          "Interdit dans tous les cas",
          "Autorisé par la droite uniquement",
          "Autorisé par la gauche uniquement",
          "Autorisé par la droite si le tramway circule au milieu de la chaussée",
        ],
        correctAnswer: "Autorisé par la droite si le tramway circule au milieu de la chaussée",
        explanation:
          "Le dépassement d'un tramway s'effectue par la droite lorsqu'il circule au milieu de la chaussée. Si le tramway circule à droite, on peut le dépasser par la gauche si la voie est libre.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation des feux de détresse ?",
        options: [
          "Uniquement en cas de panne",
          "Uniquement en cas de ralentissement brusque",
          "En cas de panne, d'accident ou de ralentissement brusque",
          "Uniquement sur autoroute",
        ],
        correctAnswer: "En cas de panne, d'accident ou de ralentissement brusque",
        explanation:
          "Les feux de détresse doivent être utilisés en cas de panne ou d'accident immobilisant le véhicule sur la chaussée, ainsi qu'en cas de ralentissement brusque sur autoroute ou voie rapide.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant le dépassement d'un véhicule qui signale qu'il va tourner à gauche ?",
        options: [
          "Interdit dans tous les cas",
          "Autorisé par la gauche uniquement",
          "Autorisé par la droite uniquement",
          "Autorisé par la gauche ou par la droite selon la configuration",
        ],
        correctAnswer: "Autorisé par la droite uniquement",
        explanation:
          "Lorsqu'un véhicule signale son intention de tourner à gauche, il est possible de le dépasser par la droite, à condition de ne pas gêner les usagers circulant sur la droite.",
      },
      {
        id: uuidv4(),
        question: "Quelle est la règle concernant l'utilisation de l'avertisseur sonore la nuit en agglomération ?",
        options: [
          "Autorisée en cas de danger immédiat",
          "Interdite, il faut utiliser les appels lumineux",
          "Autorisée uniquement pour les véhicules prioritaires",
          "Autorisée entre 22h et 6h",
        ],
        correctAnswer: "Interdite, il faut utiliser les appels lumineux",
        explanation:
          "La nuit en agglomération, l'usage de l'avertisseur sonore est interdit sauf en cas de danger immédiat. Il faut privilégier les appels lumineux (alternance rapide feux de route/feux de croisement).",
      },
    ],
  },
]

export default avanceSimulations
